# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Scriptgen(Base):
	"""The Scriptgen class encapsulates a required scriptgen node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Scriptgen property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'scriptgen'

	def __init__(self, parent):
		super(Scriptgen, self).__init__(parent)

	@property
	def Base64CodeOptions(self):
		"""An instance of the Base64CodeOptions class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.scriptgen.base64codeoptions.base64codeoptions.Base64CodeOptions)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.scriptgen.base64codeoptions.base64codeoptions import Base64CodeOptions
		return Base64CodeOptions(self)._select()

	@property
	def IxNetCodeOptions(self):
		"""An instance of the IxNetCodeOptions class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.scriptgen.ixnetcodeoptions.ixnetcodeoptions.IxNetCodeOptions)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.scriptgen.ixnetcodeoptions.ixnetcodeoptions import IxNetCodeOptions
		return IxNetCodeOptions(self)._select()

	@property
	def ConnectHostname(self):
		"""The hostname to be used in the connect command

		Returns:
			str
		"""
		return self._get_attribute('connectHostname')
	@ConnectHostname.setter
	def ConnectHostname(self, value):
		self._set_attribute('connectHostname', value)

	@property
	def ConnectPort(self):
		"""The port number to be used in the connect command

		Returns:
			number
		"""
		return self._get_attribute('connectPort')
	@ConnectPort.setter
	def ConnectPort(self, value):
		self._set_attribute('connectPort', value)

	@property
	def ConnectVersion(self):
		"""The version number to be used in the connect command

		Returns:
			str
		"""
		return self._get_attribute('connectVersion')
	@ConnectVersion.setter
	def ConnectVersion(self, value):
		self._set_attribute('connectVersion', value)

	@property
	def IncludeConnect(self):
		"""Flag to include the connect command

		Returns:
			bool
		"""
		return self._get_attribute('includeConnect')
	@IncludeConnect.setter
	def IncludeConnect(self, value):
		self._set_attribute('includeConnect', value)

	@property
	def IncludeTestComposer(self):
		"""Flag to include test composer code

		Returns:
			bool
		"""
		return self._get_attribute('includeTestComposer')
	@IncludeTestComposer.setter
	def IncludeTestComposer(self, value):
		self._set_attribute('includeTestComposer', value)

	@property
	def Language(self):
		"""Select the target scriptgen language

		Returns:
			str(perl|python|ruby|tcl)
		"""
		return self._get_attribute('language')
	@Language.setter
	def Language(self, value):
		self._set_attribute('language', value)

	@property
	def LinePerAttribute(self):
		"""If true the scriptgen output will show each attribute on a separate line

		Returns:
			bool
		"""
		return self._get_attribute('linePerAttribute')
	@LinePerAttribute.setter
	def LinePerAttribute(self, value):
		self._set_attribute('linePerAttribute', value)

	@property
	def OverwriteScriptFilename(self):
		"""If true the file indicated by the script filename will be overwritten

		Returns:
			bool
		"""
		return self._get_attribute('overwriteScriptFilename')
	@OverwriteScriptFilename.setter
	def OverwriteScriptFilename(self, value):
		self._set_attribute('overwriteScriptFilename', value)

	@property
	def ScriptFilename(self):
		"""The name of the target scriptgen file

		Returns:
			str
		"""
		return self._get_attribute('scriptFilename')
	@ScriptFilename.setter
	def ScriptFilename(self, value):
		self._set_attribute('scriptFilename', value)

	@property
	def SerializationType(self):
		"""The scriptgen serialization type

		Returns:
			str(base64|ixNet)
		"""
		return self._get_attribute('serializationType')
	@SerializationType.setter
	def SerializationType(self, value):
		self._set_attribute('serializationType', value)

	def update(self, ConnectHostname=None, ConnectPort=None, ConnectVersion=None, IncludeConnect=None, IncludeTestComposer=None, Language=None, LinePerAttribute=None, OverwriteScriptFilename=None, ScriptFilename=None, SerializationType=None):
		"""Updates a child instance of scriptgen on the server.

		Args:
			ConnectHostname (str): The hostname to be used in the connect command
			ConnectPort (number): The port number to be used in the connect command
			ConnectVersion (str): The version number to be used in the connect command
			IncludeConnect (bool): Flag to include the connect command
			IncludeTestComposer (bool): Flag to include test composer code
			Language (str(perl|python|ruby|tcl)): Select the target scriptgen language
			LinePerAttribute (bool): If true the scriptgen output will show each attribute on a separate line
			OverwriteScriptFilename (bool): If true the file indicated by the script filename will be overwritten
			ScriptFilename (str): The name of the target scriptgen file
			SerializationType (str(base64|ixNet)): The scriptgen serialization type

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Generate(self, *args, **kwargs):
		"""Executes the generate operation on the server.

		Generate a script of the currently loaded configuration using the options in the /globals/scriptgen hierarchy.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		generate()

		generate(Arg2:href)
			Args:
				args[0] is Arg2 (obj(ixnetwork_restpy.files.Files)): A valid writeTo file handle the script will be written to.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('generate', payload=payload, response_object=None)



""" Demonstrates IxNetwork Linux API Server session management
"""

from ixnetwork_restpy.testplatform.testplatform import TestPlatform


# setup the connection information for a windows gui test platform that has a default session of 1
# platform='linux' forces the scheme to https
# if the default platform='windows' is used a ConnectionError will be raised
# as the Linux API Server does not redirect but closes the connection
test_platform=TestPlatform('10.36.74.17', platform='linux')
test_platform.Trace = 'request_response'

# authenticate with username and password
test_platform.Authenticate('admin', 'admin')
api_key = test_platform.ApiKey

# if username/password is not acceptable to the client due to the unencrypted password
# an api key can be specified instead
# the api key can be retrieved from the linux api server user settings and provided 
# to the TestPlatform.ApiKey property which will be used in subsequent server requests
test_platform.ApiKey = api_key

# get a list of sessions
for session in test_platform.Sessions.find():
    print(session)

# add a session
sessions = test_platform.Sessions.add()
session_id = sessions.Id
print(sessions)

# remove the session
sessions.remove()
assert (len(sessions) == 0)

# attempt to get the removed session
sessions = test_platform.Sessions.find(session_id)
assert(len(sessions) == 0)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Instructions(Base):
	"""The Instructions class encapsulates a user managed instructions node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Instructions property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'instructions'

	def __init__(self, parent):
		super(Instructions, self).__init__(parent)

	@property
	def InstructionActions(self):
		"""An instance of the InstructionActions class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.instructionactions.InstructionActions)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.instructionactions import InstructionActions
		return InstructionActions(self)

	@property
	def Experimenter(self):
		"""The unique identifier for the Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('experimenter')
	@Experimenter.setter
	def Experimenter(self, value):
		self._set_attribute('experimenter', value)

	@property
	def ExperimenterData(self):
		"""The experimenter data field value.

		Returns:
			str
		"""
		return self._get_attribute('experimenterData')
	@ExperimenterData.setter
	def ExperimenterData(self, value):
		self._set_attribute('experimenterData', value)

	@property
	def ExperimenterDataLength(self):
		"""The Value of the data length of the Experimenter. The default value is 1.

		Returns:
			number
		"""
		return self._get_attribute('experimenterDataLength')
	@ExperimenterDataLength.setter
	def ExperimenterDataLength(self, value):
		self._set_attribute('experimenterDataLength', value)

	@property
	def InstructionType(self):
		"""The instruction type associated with this Flow Range.

		Returns:
			str(meter|applyActions|clearActions|experimenter|goToTable|writeActions|writeMetadata)
		"""
		return self._get_attribute('instructionType')
	@InstructionType.setter
	def InstructionType(self, value):
		self._set_attribute('instructionType', value)

	@property
	def Metadata(self):
		"""Value of the metadata field.

		Returns:
			str
		"""
		return self._get_attribute('metadata')
	@Metadata.setter
	def Metadata(self, value):
		self._set_attribute('metadata', value)

	@property
	def MetadataInHex(self):
		"""Specify the table metadata value in hexadecimal format.

		Returns:
			str
		"""
		return self._get_attribute('metadataInHex')
	@MetadataInHex.setter
	def MetadataInHex(self, value):
		self._set_attribute('metadataInHex', value)

	@property
	def MetadataMask(self):
		"""Specify the metadata bitmask value.

		Returns:
			str
		"""
		return self._get_attribute('metadataMask')
	@MetadataMask.setter
	def MetadataMask(self, value):
		self._set_attribute('metadataMask', value)

	@property
	def MeterId(self):
		"""The value by which a meter is uniquely identified within a switch. The default value is 1.

		Returns:
			number
		"""
		return self._get_attribute('meterId')
	@MeterId.setter
	def MeterId(self, value):
		self._set_attribute('meterId', value)

	@property
	def TableId(self):
		"""The ID of the table to go to.

		Returns:
			number
		"""
		return self._get_attribute('tableId')
	@TableId.setter
	def TableId(self, value):
		self._set_attribute('tableId', value)

	def update(self, Experimenter=None, ExperimenterData=None, ExperimenterDataLength=None, InstructionType=None, Metadata=None, MetadataInHex=None, MetadataMask=None, MeterId=None, TableId=None):
		"""Updates a child instance of instructions on the server.

		Args:
			Experimenter (number): The unique identifier for the Experimenter.
			ExperimenterData (str): The experimenter data field value.
			ExperimenterDataLength (number): The Value of the data length of the Experimenter. The default value is 1.
			InstructionType (str(meter|applyActions|clearActions|experimenter|goToTable|writeActions|writeMetadata)): The instruction type associated with this Flow Range.
			Metadata (str): Value of the metadata field.
			MetadataInHex (str): Specify the table metadata value in hexadecimal format.
			MetadataMask (str): Specify the metadata bitmask value.
			MeterId (number): The value by which a meter is uniquely identified within a switch. The default value is 1.
			TableId (number): The ID of the table to go to.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, Experimenter=None, ExperimenterData=None, ExperimenterDataLength=None, InstructionType=None, Metadata=None, MetadataInHex=None, MetadataMask=None, MeterId=None, TableId=None):
		"""Adds a new instructions node on the server and retrieves it in this instance.

		Args:
			Experimenter (number): The unique identifier for the Experimenter.
			ExperimenterData (str): The experimenter data field value.
			ExperimenterDataLength (number): The Value of the data length of the Experimenter. The default value is 1.
			InstructionType (str(meter|applyActions|clearActions|experimenter|goToTable|writeActions|writeMetadata)): The instruction type associated with this Flow Range.
			Metadata (str): Value of the metadata field.
			MetadataInHex (str): Specify the table metadata value in hexadecimal format.
			MetadataMask (str): Specify the metadata bitmask value.
			MeterId (number): The value by which a meter is uniquely identified within a switch. The default value is 1.
			TableId (number): The ID of the table to go to.

		Returns:
			self: This instance with all currently retrieved instructions data using find and the newly added instructions data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the instructions data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Experimenter=None, ExperimenterData=None, ExperimenterDataLength=None, InstructionType=None, Metadata=None, MetadataInHex=None, MetadataMask=None, MeterId=None, TableId=None):
		"""Finds and retrieves instructions data from the server.

		All named parameters support regex and can be used to selectively retrieve instructions data from the server.
		By default the find method takes no parameters and will retrieve all instructions data from the server.

		Args:
			Experimenter (number): The unique identifier for the Experimenter.
			ExperimenterData (str): The experimenter data field value.
			ExperimenterDataLength (number): The Value of the data length of the Experimenter. The default value is 1.
			InstructionType (str(meter|applyActions|clearActions|experimenter|goToTable|writeActions|writeMetadata)): The instruction type associated with this Flow Range.
			Metadata (str): Value of the metadata field.
			MetadataInHex (str): Specify the table metadata value in hexadecimal format.
			MetadataMask (str): Specify the metadata bitmask value.
			MeterId (number): The value by which a meter is uniquely identified within a switch. The default value is 1.
			TableId (number): The ID of the table to go to.

		Returns:
			self: This instance with matching instructions data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of instructions data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the instructions data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



"""Demonstrates some best practices for specifying device ids when executing ngpf operations

"""

from ixnetwork_restpy.testplatform.testplatform import TestPlatform


# connect to a test platform, create a session and get the root IxNetwork object
test_platform = TestPlatform('127.0.0.1', rest_port=11009)
test_platform.Trace = 'request_response'
sessions = test_platform.Sessions.find(Id=1)
ixnetwork = sessions.Ixnetwork
ixnetwork.NewConfig()

# create a b2b ngpf scenario
vport_1 = ixnetwork.Vport.add().add().add()
print(vport_1)
vport_2 = ixnetwork.Vport.add()
topologies = ixnetwork.Topology.add(Vports=vport_1).add(Vports=vport_2)
ipv4_1 = topologies[0].DeviceGroup.add().Ethernet.add().Ipv4.add()
igmp_host = ipv4_1.IgmpHost.add()
ipv4_2 = topologies[1].DeviceGroup.add().Ethernet.add().Ipv4.add()
igmp_querier = ipv4_2.IgmpQuerier.add()

# set the port step on the address
address = ipv4_1.Address
print(address.Steps)
address.Steps.Step = '1.1.1.1'
assert(address.Steps.Step == '1.1.1.1')

# get device ids for two specific ip addresses
ipv4_device_ids = ipv4_1.get_device_ids(Address='^(%s|%s)' % (ipv4_1.Address.Values[6], ipv4_1.Address.Values[24]))
assert(len(ipv4_device_ids) == 2)

# get device ids on two specific ports
port_device_ids = ipv4_1.get_device_ids(PortNames='^(%s|%s)$' % (vport_1[0].Name, vport_1[2].Name))
assert(len(port_device_ids) == 20)

# get device ids for igmp v2 hosts on a specific port
v2_device_ids = igmp_host.get_device_ids(PortNames='(?i)^%s$' % (vport_1[1].Name), VersionType='(?i)version2')
assert(len(v2_device_ids) == 10)

# stop all devices
ipv4_1.Stop()

# start only a few devices
ipv4_1.Start(ipv4_device_ids)

# leave
igmp_host.IgmpMcastIPv4GroupList.IgmpLeaveGroup("1-4;6")

# issue a join on only a few devices
igmp_host.IgmpMcastIPv4GroupList.Join(v2_device_ids)







# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class MldHost(Base):
	"""The MldHost class encapsulates a user managed mldHost node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the MldHost property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'mldHost'

	def __init__(self, parent):
		super(MldHost, self).__init__(parent)

	@property
	def Iptv(self):
		"""An instance of the Iptv class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.iptv.Iptv)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.iptv import Iptv
		return Iptv(self)._select()

	@property
	def MldMcastIPv6GroupList(self):
		"""An instance of the MldMcastIPv6GroupList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.mldmcastipv6grouplist.MldMcastIPv6GroupList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.mldmcastipv6grouplist import MldMcastIPv6GroupList
		return MldMcastIPv6GroupList(self)._select()

	@property
	def Tag(self):
		"""An instance of the Tag class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag.Tag)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag import Tag
		return Tag(self)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def ConnectedVia(self):
		"""DEPRECATED List of layers this layer used to connect to the wire

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('connectedVia')
	@ConnectedVia.setter
	def ConnectedVia(self, value):
		self._set_attribute('connectedVia', value)

	@property
	def Count(self):
		"""DEPRECATED Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""DEPRECATED Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def EnableIptv(self):
		"""DEPRECATED Enable IPTV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableIptv')

	@property
	def EnableProxyReporting(self):
		"""DEPRECATED Enable Proxy Reporting

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableProxyReporting')

	@property
	def Errors(self):
		"""DEPRECATED A list of errors that have occurred

		Returns:
			list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))
		"""
		return self._get_attribute('errors')

	@property
	def GQResponseMode(self):
		"""DEPRECATED General Query Response Mode

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('gQResponseMode')

	@property
	def GSResponseMode(self):
		"""DEPRECATED Group Specific Response Mode

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('gSResponseMode')

	@property
	def ImResponse(self):
		"""DEPRECATED Immediate Response

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('imResponse')

	@property
	def JlMultiplier(self):
		"""DEPRECATED No. of Join/Leave messages to send per opertation

		Returns:
			number
		"""
		return self._get_attribute('jlMultiplier')
	@JlMultiplier.setter
	def JlMultiplier(self, value):
		self._set_attribute('jlMultiplier', value)

	@property
	def Multiplier(self):
		"""DEPRECATED Number of layer instances per parent instance (multiplier)

		Returns:
			number
		"""
		return self._get_attribute('multiplier')
	@Multiplier.setter
	def Multiplier(self, value):
		self._set_attribute('multiplier', value)

	@property
	def Name(self):
		"""DEPRECATED Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def NoOfGrpRanges(self):
		"""DEPRECATED Defines the number of group range per host required

		Returns:
			number
		"""
		return self._get_attribute('noOfGrpRanges')
	@NoOfGrpRanges.setter
	def NoOfGrpRanges(self, value):
		self._set_attribute('noOfGrpRanges', value)

	@property
	def ReportFreq(self):
		"""DEPRECATED Report Frequency measured in seconds

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('reportFreq')

	@property
	def RouterAlert(self):
		"""DEPRECATED Enables Router Alert option of IPv4 Packet

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('routerAlert')

	@property
	def SessionStatus(self):
		"""DEPRECATED Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.

		Returns:
			list(str[down|notStarted|up])
		"""
		return self._get_attribute('sessionStatus')

	@property
	def StackedLayers(self):
		"""DEPRECATED List of secondary (many to one) child layer protocols

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('stackedLayers')
	@StackedLayers.setter
	def StackedLayers(self, value):
		self._set_attribute('stackedLayers', value)

	@property
	def StateCounts(self):
		"""DEPRECATED A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up

		Returns:
			dict(total:number,notStarted:number,down:number,up:number)
		"""
		return self._get_attribute('stateCounts')

	@property
	def Status(self):
		"""DEPRECATED Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			str(configured|error|mixed|notStarted|started|starting|stopping)
		"""
		return self._get_attribute('status')

	@property
	def USResponseMode(self):
		"""DEPRECATED Unsolicited Response Mode

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('uSResponseMode')

	@property
	def VersionType(self):
		"""DEPRECATED Specifies the MLD Version Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('versionType')

	def update(self, ConnectedVia=None, JlMultiplier=None, Multiplier=None, Name=None, NoOfGrpRanges=None, StackedLayers=None):
		"""Updates a child instance of mldHost on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			JlMultiplier (number): No. of Join/Leave messages to send per opertation
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NoOfGrpRanges (number): Defines the number of group range per host required
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, ConnectedVia=None, JlMultiplier=None, Multiplier=None, Name=None, NoOfGrpRanges=None, StackedLayers=None):
		"""Adds a new mldHost node on the server and retrieves it in this instance.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			JlMultiplier (number): No. of Join/Leave messages to send per opertation
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NoOfGrpRanges (number): Defines the number of group range per host required
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Returns:
			self: This instance with all currently retrieved mldHost data using find and the newly added mldHost data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the mldHost data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, ConnectedVia=None, Count=None, DescriptiveName=None, Errors=None, JlMultiplier=None, Multiplier=None, Name=None, NoOfGrpRanges=None, SessionStatus=None, StackedLayers=None, StateCounts=None, Status=None):
		"""Finds and retrieves mldHost data from the server.

		All named parameters support regex and can be used to selectively retrieve mldHost data from the server.
		By default the find method takes no parameters and will retrieve all mldHost data from the server.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			Errors (list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))): A list of errors that have occurred
			JlMultiplier (number): No. of Join/Leave messages to send per opertation
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NoOfGrpRanges (number): Defines the number of group range per host required
			SessionStatus (list(str[down|notStarted|up])): Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			StateCounts (dict(total:number,notStarted:number,down:number,up:number)): A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up
			Status (str(configured|error|mixed|notStarted|started|starting|stopping)): Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			self: This instance with matching mldHost data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of mldHost data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the mldHost data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, Active=None, EnableIptv=None, EnableProxyReporting=None, GQResponseMode=None, GSResponseMode=None, ImResponse=None, ReportFreq=None, RouterAlert=None, USResponseMode=None, VersionType=None):
		"""Base class infrastructure that gets a list of mldHost device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			EnableIptv (str): optional regex of enableIptv
			EnableProxyReporting (str): optional regex of enableProxyReporting
			GQResponseMode (str): optional regex of gQResponseMode
			GSResponseMode (str): optional regex of gSResponseMode
			ImResponse (str): optional regex of imResponse
			ReportFreq (str): optional regex of reportFreq
			RouterAlert (str): optional regex of routerAlert
			USResponseMode (str): optional regex of uSResponseMode
			VersionType (str): optional regex of versionType

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def MldStartHost(self, *args, **kwargs):
		"""Executes the mldStartHost operation on the server.

		Start MLD Host

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		mldStartHost()

		mldStartHost(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		mldStartHost(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('mldStartHost', payload=payload, response_object=None)

	def MldStopHost(self, *args, **kwargs):
		"""Executes the mldStopHost operation on the server.

		Stop MLD Host

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		mldStopHost()

		mldStopHost(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		mldStopHost(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('mldStopHost', payload=payload, response_object=None)

	def RestartDown(self, *args, **kwargs):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		restartDown()

		restartDown(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		restartDown(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('restartDown', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Start selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def StartMLD(self, *args, **kwargs):
		"""Executes the startMLD operation on the server.

		Start MLD protocol on selected interfaces

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		startMLD()

		startMLD(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		startMLD(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		startMLD(Arg2:string, Arg3:list)
			Args:
				args[0] is Arg2 (str): ID to associate each async action invocation
				args[1] is Arg3 (list(number)): List of indices into the group range grid An empty list indicates all instances in the plugin.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('startMLD', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Stop selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)

	def StopMLD(self, *args, **kwargs):
		"""Executes the stopMLD operation on the server.

		Stop MLD protocol on selected interfaces

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stopMLD()

		stopMLD(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stopMLD(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		stopMLD(Arg2:string, Arg3:list)
			Args:
				args[0] is Arg2 (str): ID to associate each async action invocation
				args[1] is Arg3 (list(number)): List of indices into the group range grid An empty list indicates all instances in the plugin.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stopMLD', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class TestConfig(Base):
	"""The TestConfig class encapsulates a required testConfig node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the TestConfig property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'testConfig'

	def __init__(self, parent):
		super(TestConfig, self).__init__(parent)

	@property
	def CalculateJitter(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('calculateJitter')
	@CalculateJitter.setter
	def CalculateJitter(self, value):
		self._set_attribute('calculateJitter', value)

	@property
	def CalculateLatency(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('calculateLatency')
	@CalculateLatency.setter
	def CalculateLatency(self, value):
		self._set_attribute('calculateLatency', value)

	@property
	def CustomLoadUnit(self):
		"""

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('customLoadUnit')
	@CustomLoadUnit.setter
	def CustomLoadUnit(self, value):
		self._set_attribute('customLoadUnit', value)

	@property
	def DetailedResultsEnabled(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('detailedResultsEnabled')
	@DetailedResultsEnabled.setter
	def DetailedResultsEnabled(self, value):
		self._set_attribute('detailedResultsEnabled', value)

	@property
	def Duration(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('duration')
	@Duration.setter
	def Duration(self, value):
		self._set_attribute('duration', value)

	@property
	def EnableDataIntegrity(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('enableDataIntegrity')
	@EnableDataIntegrity.setter
	def EnableDataIntegrity(self, value):
		self._set_attribute('enableDataIntegrity', value)

	@property
	def EnableLayer1Rate(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('enableLayer1Rate')
	@EnableLayer1Rate.setter
	def EnableLayer1Rate(self, value):
		self._set_attribute('enableLayer1Rate', value)

	@property
	def FixedFrameSize(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('fixedFrameSize')
	@FixedFrameSize.setter
	def FixedFrameSize(self, value):
		self._set_attribute('fixedFrameSize', value)

	@property
	def FloodedFramesEnabled(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('floodedFramesEnabled')
	@FloodedFramesEnabled.setter
	def FloodedFramesEnabled(self, value):
		self._set_attribute('floodedFramesEnabled', value)

	@property
	def ForceContinuosTraffic(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('forceContinuosTraffic')
	@ForceContinuosTraffic.setter
	def ForceContinuosTraffic(self, value):
		self._set_attribute('forceContinuosTraffic', value)

	@property
	def FrameSizeMode(self):
		"""

		Returns:
			str(fixed)
		"""
		return self._get_attribute('frameSizeMode')
	@FrameSizeMode.setter
	def FrameSizeMode(self, value):
		self._set_attribute('frameSizeMode', value)

	@property
	def Gap(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('gap')
	@Gap.setter
	def Gap(self, value):
		self._set_attribute('gap', value)

	@property
	def IpRatioMode(self):
		"""

		Returns:
			str(custom|fixed|increment|random)
		"""
		return self._get_attribute('ipRatioMode')
	@IpRatioMode.setter
	def IpRatioMode(self, value):
		self._set_attribute('ipRatioMode', value)

	@property
	def Ipv4rate(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('ipv4rate')
	@Ipv4rate.setter
	def Ipv4rate(self, value):
		self._set_attribute('ipv4rate', value)

	@property
	def Ipv6rate(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('ipv6rate')
	@Ipv6rate.setter
	def Ipv6rate(self, value):
		self._set_attribute('ipv6rate', value)

	@property
	def LatencyType(self):
		"""

		Returns:
			str(cutThrough|forwardingDelay|mef|storeForward)
		"""
		return self._get_attribute('latencyType')
	@LatencyType.setter
	def LatencyType(self, value):
		self._set_attribute('latencyType', value)

	@property
	def LoadRateValue(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('loadRateValue')
	@LoadRateValue.setter
	def LoadRateValue(self, value):
		self._set_attribute('loadRateValue', value)

	@property
	def LoadType(self):
		"""

		Returns:
			str(binary|combo|custom|fixed|increment|quickSearch|random|step|unchanged)
		"""
		return self._get_attribute('loadType')
	@LoadType.setter
	def LoadType(self, value):
		self._set_attribute('loadType', value)

	@property
	def Numtrials(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('numtrials')
	@Numtrials.setter
	def Numtrials(self, value):
		self._set_attribute('numtrials', value)

	@property
	def ProtocolItem(self):
		"""Protocol Items

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])
		"""
		return self._get_attribute('protocolItem')
	@ProtocolItem.setter
	def ProtocolItem(self, value):
		self._set_attribute('protocolItem', value)

	@property
	def ReportSequenceError(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('reportSequenceError')
	@ReportSequenceError.setter
	def ReportSequenceError(self, value):
		self._set_attribute('reportSequenceError', value)

	@property
	def ReportTputRateUnit(self):
		"""

		Returns:
			str(gbps|gBps|kbps|kBps|mbps|mBps)
		"""
		return self._get_attribute('reportTputRateUnit')
	@ReportTputRateUnit.setter
	def ReportTputRateUnit(self, value):
		self._set_attribute('reportTputRateUnit', value)

	@property
	def TrafficType(self):
		"""

		Returns:
			str(burstyLoading|constantLoading)
		"""
		return self._get_attribute('trafficType')
	@TrafficType.setter
	def TrafficType(self, value):
		self._set_attribute('trafficType', value)

	def update(self, CalculateJitter=None, CalculateLatency=None, CustomLoadUnit=None, DetailedResultsEnabled=None, Duration=None, EnableDataIntegrity=None, EnableLayer1Rate=None, FixedFrameSize=None, FloodedFramesEnabled=None, ForceContinuosTraffic=None, FrameSizeMode=None, Gap=None, IpRatioMode=None, Ipv4rate=None, Ipv6rate=None, LatencyType=None, LoadRateValue=None, LoadType=None, Numtrials=None, ProtocolItem=None, ReportSequenceError=None, ReportTputRateUnit=None, TrafficType=None):
		"""Updates a child instance of testConfig on the server.

		Args:
			CalculateJitter (bool): 
			CalculateLatency (bool): 
			CustomLoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): 
			DetailedResultsEnabled (bool): 
			Duration (number): 
			EnableDataIntegrity (bool): 
			EnableLayer1Rate (bool): 
			FixedFrameSize (number): 
			FloodedFramesEnabled (bool): 
			ForceContinuosTraffic (bool): 
			FrameSizeMode (str(fixed)): 
			Gap (number): 
			IpRatioMode (str(custom|fixed|increment|random)): 
			Ipv4rate (number): 
			Ipv6rate (number): 
			LatencyType (str(cutThrough|forwardingDelay|mef|storeForward)): 
			LoadRateValue (number): 
			LoadType (str(binary|combo|custom|fixed|increment|quickSearch|random|step|unchanged)): 
			Numtrials (number): 
			ProtocolItem (list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])): Protocol Items
			ReportSequenceError (bool): 
			ReportTputRateUnit (str(gbps|gBps|kbps|kBps|mbps|mBps)): 
			TrafficType (str(burstyLoading|constantLoading)): 

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Apply(self):
		"""Executes the apply operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('apply', payload=payload, response_object=None)

	def ApplyAsync(self):
		"""Executes the applyAsync operation on the server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsync', payload=payload, response_object=None)

	def ApplyAsyncResult(self):
		"""Executes the applyAsyncResult operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsyncResult', payload=payload, response_object=None)

	def ApplyITWizardConfiguration(self):
		"""Executes the applyITWizardConfiguration operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyITWizardConfiguration', payload=payload, response_object=None)

	def GenerateReport(self):
		"""Executes the generateReport operation on the server.

		Generate a PDF report for the last succesfull test run.

			Returns:
				str: This method is asynchronous and has no return value.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('generateReport', payload=payload, response_object=None)

	def Run(self, *args, **kwargs):
		"""Executes the run operation on the server.

		Starts the specified Quick Test and waits for its execution to finish.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		run()list

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		run(InputParameters:string)list
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('run', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Starts the specified Quick Test.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(InputParameters:string)
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stops the currently running Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)

	def WaitForTest(self):
		"""Executes the waitForTest operation on the server.

		Waits for the execution of the specified Quick Test to be completed.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('waitForTest', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class ItrRemoteEidRange(Base):
	"""The ItrRemoteEidRange class encapsulates a user managed itrRemoteEidRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the ItrRemoteEidRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'itrRemoteEidRange'

	def __init__(self, parent):
		super(ItrRemoteEidRange, self).__init__(parent)

	@property
	def Count(self):
		"""it gives details about the count

		Returns:
			number
		"""
		return self._get_attribute('count')
	@Count.setter
	def Count(self, value):
		self._set_attribute('count', value)

	@property
	def EnableMapReplyRecordSegmentMbit(self):
		"""If true, it enables Map reply record Segment Mbit

		Returns:
			bool
		"""
		return self._get_attribute('enableMapReplyRecordSegmentMbit')
	@EnableMapReplyRecordSegmentMbit.setter
	def EnableMapReplyRecordSegmentMbit(self, value):
		self._set_attribute('enableMapReplyRecordSegmentMbit', value)

	@property
	def Enabled(self):
		"""If true, it gives details about then protocol

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def Family(self):
		"""It gives details about the IP family it represents

		Returns:
			str(ipv4|ipv6)
		"""
		return self._get_attribute('family')
	@Family.setter
	def Family(self, value):
		self._set_attribute('family', value)

	@property
	def KeepQueryingUnlessResolved(self):
		"""If true, it keeps Querying Unless resolved

		Returns:
			bool
		"""
		return self._get_attribute('keepQueryingUnlessResolved')
	@KeepQueryingUnlessResolved.setter
	def KeepQueryingUnlessResolved(self, value):
		self._set_attribute('keepQueryingUnlessResolved', value)

	@property
	def MapResolvingInterval(self):
		"""It gives the map resolving interval

		Returns:
			number
		"""
		return self._get_attribute('mapResolvingInterval')
	@MapResolvingInterval.setter
	def MapResolvingInterval(self, value):
		self._set_attribute('mapResolvingInterval', value)

	@property
	def PrefixLength(self):
		"""it gives the prefix length

		Returns:
			number
		"""
		return self._get_attribute('prefixLength')
	@PrefixLength.setter
	def PrefixLength(self, value):
		self._set_attribute('prefixLength', value)

	@property
	def QueryIntervalUnlessResolved(self):
		"""It gives the query regarding the interval unless resolved

		Returns:
			number
		"""
		return self._get_attribute('queryIntervalUnlessResolved')
	@QueryIntervalUnlessResolved.setter
	def QueryIntervalUnlessResolved(self, value):
		self._set_attribute('queryIntervalUnlessResolved', value)

	@property
	def StartAddress(self):
		"""It gives details about the start address

		Returns:
			str
		"""
		return self._get_attribute('startAddress')
	@StartAddress.setter
	def StartAddress(self, value):
		self._set_attribute('startAddress', value)

	def update(self, Count=None, EnableMapReplyRecordSegmentMbit=None, Enabled=None, Family=None, KeepQueryingUnlessResolved=None, MapResolvingInterval=None, PrefixLength=None, QueryIntervalUnlessResolved=None, StartAddress=None):
		"""Updates a child instance of itrRemoteEidRange on the server.

		Args:
			Count (number): it gives details about the count
			EnableMapReplyRecordSegmentMbit (bool): If true, it enables Map reply record Segment Mbit
			Enabled (bool): If true, it gives details about then protocol
			Family (str(ipv4|ipv6)): It gives details about the IP family it represents
			KeepQueryingUnlessResolved (bool): If true, it keeps Querying Unless resolved
			MapResolvingInterval (number): It gives the map resolving interval
			PrefixLength (number): it gives the prefix length
			QueryIntervalUnlessResolved (number): It gives the query regarding the interval unless resolved
			StartAddress (str): It gives details about the start address

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, Count=None, EnableMapReplyRecordSegmentMbit=None, Enabled=None, Family=None, KeepQueryingUnlessResolved=None, MapResolvingInterval=None, PrefixLength=None, QueryIntervalUnlessResolved=None, StartAddress=None):
		"""Adds a new itrRemoteEidRange node on the server and retrieves it in this instance.

		Args:
			Count (number): it gives details about the count
			EnableMapReplyRecordSegmentMbit (bool): If true, it enables Map reply record Segment Mbit
			Enabled (bool): If true, it gives details about then protocol
			Family (str(ipv4|ipv6)): It gives details about the IP family it represents
			KeepQueryingUnlessResolved (bool): If true, it keeps Querying Unless resolved
			MapResolvingInterval (number): It gives the map resolving interval
			PrefixLength (number): it gives the prefix length
			QueryIntervalUnlessResolved (number): It gives the query regarding the interval unless resolved
			StartAddress (str): It gives details about the start address

		Returns:
			self: This instance with all currently retrieved itrRemoteEidRange data using find and the newly added itrRemoteEidRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the itrRemoteEidRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Count=None, EnableMapReplyRecordSegmentMbit=None, Enabled=None, Family=None, KeepQueryingUnlessResolved=None, MapResolvingInterval=None, PrefixLength=None, QueryIntervalUnlessResolved=None, StartAddress=None):
		"""Finds and retrieves itrRemoteEidRange data from the server.

		All named parameters support regex and can be used to selectively retrieve itrRemoteEidRange data from the server.
		By default the find method takes no parameters and will retrieve all itrRemoteEidRange data from the server.

		Args:
			Count (number): it gives details about the count
			EnableMapReplyRecordSegmentMbit (bool): If true, it enables Map reply record Segment Mbit
			Enabled (bool): If true, it gives details about then protocol
			Family (str(ipv4|ipv6)): It gives details about the IP family it represents
			KeepQueryingUnlessResolved (bool): If true, it keeps Querying Unless resolved
			MapResolvingInterval (number): It gives the map resolving interval
			PrefixLength (number): it gives the prefix length
			QueryIntervalUnlessResolved (number): It gives the query regarding the interval unless resolved
			StartAddress (str): It gives details about the start address

		Returns:
			self: This instance with matching itrRemoteEidRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of itrRemoteEidRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the itrRemoteEidRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class PceDetailedSrSyncLspUpdateParams(Base):
	"""The PceDetailedSrSyncLspUpdateParams class encapsulates a system managed pceDetailedSrSyncLspUpdateParams node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the PceDetailedSrSyncLspUpdateParams property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'pceDetailedSrSyncLspUpdateParams'

	def __init__(self, parent):
		super(PceDetailedSrSyncLspUpdateParams, self).__init__(parent)

	@property
	def PceUpdateSrEroSubObjectList(self):
		"""An instance of the PceUpdateSrEroSubObjectList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.pceupdatesrerosubobjectlist.PceUpdateSrEroSubObjectList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.pceupdatesrerosubobjectlist import PceUpdateSrEroSubObjectList
		return PceUpdateSrEroSubObjectList(self)

	@property
	def PceUpdateSrMetricSubObjectList(self):
		"""An instance of the PceUpdateSrMetricSubObjectList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.pceupdatesrmetricsubobjectlist.PceUpdateSrMetricSubObjectList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.pceupdatesrmetricsubobjectlist import PceUpdateSrMetricSubObjectList
		return PceUpdateSrMetricSubObjectList(self)

	@property
	def Bandwidth(self):
		"""Bandwidth (bps)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bandwidth')

	@property
	def BindingType(self):
		"""Indicates the type of binding included in the TLV. Types are as follows: 20bit MPLS Label 32bit MPLS Label. Default value is 20bit MPLS Label.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bindingType')

	@property
	def Bos(self):
		"""This bit is set to True for the last entry in the label stack i.e., for the bottom of the stack, and False for all other label stack entries. This control will be editable only if Binding Type is MPLS Label 32bit.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bos')

	@property
	def ConfigureBandwidth(self):
		"""Configure Bandwidth

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('configureBandwidth')

	@property
	def ConfigureEro(self):
		"""Configure ERO

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('configureEro')

	@property
	def ConfigureLsp(self):
		"""Configure LSP

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('configureLsp')

	@property
	def ConfigureLspa(self):
		"""Configure LSPA

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('configureLspa')

	@property
	def ConfigureMetric(self):
		"""Configure Metric

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('configureMetric')

	@property
	def ExcludeAny(self):
		"""Exclude Any

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('excludeAny')

	@property
	def HoldingPriority(self):
		"""Holding Priority

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('holdingPriority')

	@property
	def IncludeAll(self):
		"""Include All

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includeAll')

	@property
	def IncludeAny(self):
		"""Include Any

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includeAny')

	@property
	def IncludeSrp(self):
		"""Indicates whether SRP object will be included in a PCInitiate message. All other attributes in sub-tab-SRP would be editable only if this checkbox is enabled.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includeSrp')

	@property
	def IncludeSymbolicPathName(self):
		"""Indicates if Symbolic-Path-Name TLV is to be included in PCUpate trigger message.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includeSymbolicPathName')

	@property
	def IncludeTEPathBindingTLV(self):
		"""Indicates if TE-PATH-BINDING TLV is to be included in PCUpate trigger message.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includeTEPathBindingTLV')

	@property
	def LocalProtection(self):
		"""Local Protection

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('localProtection')

	@property
	def MplsLabel(self):
		"""This control will be editable if the Binding Type is set to either 20bit or 32bit MPLS-Label. This field will take the 20bit value of the MPLS-Label

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mplsLabel')

	@property
	def NumberOfEroSubObjects(self):
		"""Value that indicates the number of ERO Sub Objects to be configured.

		Returns:
			number
		"""
		return self._get_attribute('numberOfEroSubObjects')
	@NumberOfEroSubObjects.setter
	def NumberOfEroSubObjects(self, value):
		self._set_attribute('numberOfEroSubObjects', value)

	@property
	def NumberOfMetricSubObjects(self):
		"""Value that indicates the number of Metric Objects to be configured.

		Returns:
			number
		"""
		return self._get_attribute('numberOfMetricSubObjects')
	@NumberOfMetricSubObjects.setter
	def NumberOfMetricSubObjects(self, value):
		self._set_attribute('numberOfMetricSubObjects', value)

	@property
	def OverrideSrpId(self):
		"""Indicates whether SRP object will be included in a PCUpdate trigger parameters. All other attributes in sub-tab-SRP would be editable only if this checkbox is enabled.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('overrideSrpId')

	@property
	def PceTriggersChoiceList(self):
		"""Based on options selected, IxNetwork sends information to PCPU and refreshes the statistical data in the corresponding tab of Learned Information

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('pceTriggersChoiceList')

	@property
	def SendEmptyTLV(self):
		"""If enabled all fields after Binding Type will be grayed out.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sendEmptyTLV')

	@property
	def SetupPriority(self):
		"""Setup Priority

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('setupPriority')

	@property
	def SrpId(self):
		"""The SRP object is used to correlate between initiation requests sent by the PCE and the error reports and state reports sent by the PCC. This number is unique per PCEP session and is incremented per initiation.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('srpId')

	@property
	def Tc(self):
		"""This field is used to carry traffic class information. This control will be editable only if Binding Type is MPLS Label 32bit.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('tc')

	@property
	def Ttl(self):
		"""This field is used to encode a time-to-live value. This control will be editable only if Binding Type is MPLS Label 32bit.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ttl')

	def update(self, NumberOfEroSubObjects=None, NumberOfMetricSubObjects=None):
		"""Updates a child instance of pceDetailedSrSyncLspUpdateParams on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			NumberOfEroSubObjects (number): Value that indicates the number of ERO Sub Objects to be configured.
			NumberOfMetricSubObjects (number): Value that indicates the number of Metric Objects to be configured.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, NumberOfEroSubObjects=None, NumberOfMetricSubObjects=None):
		"""Finds and retrieves pceDetailedSrSyncLspUpdateParams data from the server.

		All named parameters support regex and can be used to selectively retrieve pceDetailedSrSyncLspUpdateParams data from the server.
		By default the find method takes no parameters and will retrieve all pceDetailedSrSyncLspUpdateParams data from the server.

		Args:
			NumberOfEroSubObjects (number): Value that indicates the number of ERO Sub Objects to be configured.
			NumberOfMetricSubObjects (number): Value that indicates the number of Metric Objects to be configured.

		Returns:
			self: This instance with matching pceDetailedSrSyncLspUpdateParams data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of pceDetailedSrSyncLspUpdateParams data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the pceDetailedSrSyncLspUpdateParams data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, Bandwidth=None, BindingType=None, Bos=None, ConfigureBandwidth=None, ConfigureEro=None, ConfigureLsp=None, ConfigureLspa=None, ConfigureMetric=None, ExcludeAny=None, HoldingPriority=None, IncludeAll=None, IncludeAny=None, IncludeSrp=None, IncludeSymbolicPathName=None, IncludeTEPathBindingTLV=None, LocalProtection=None, MplsLabel=None, OverrideSrpId=None, PceTriggersChoiceList=None, SendEmptyTLV=None, SetupPriority=None, SrpId=None, Tc=None, Ttl=None):
		"""Base class infrastructure that gets a list of pceDetailedSrSyncLspUpdateParams device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Bandwidth (str): optional regex of bandwidth
			BindingType (str): optional regex of bindingType
			Bos (str): optional regex of bos
			ConfigureBandwidth (str): optional regex of configureBandwidth
			ConfigureEro (str): optional regex of configureEro
			ConfigureLsp (str): optional regex of configureLsp
			ConfigureLspa (str): optional regex of configureLspa
			ConfigureMetric (str): optional regex of configureMetric
			ExcludeAny (str): optional regex of excludeAny
			HoldingPriority (str): optional regex of holdingPriority
			IncludeAll (str): optional regex of includeAll
			IncludeAny (str): optional regex of includeAny
			IncludeSrp (str): optional regex of includeSrp
			IncludeSymbolicPathName (str): optional regex of includeSymbolicPathName
			IncludeTEPathBindingTLV (str): optional regex of includeTEPathBindingTLV
			LocalProtection (str): optional regex of localProtection
			MplsLabel (str): optional regex of mplsLabel
			OverrideSrpId (str): optional regex of overrideSrpId
			PceTriggersChoiceList (str): optional regex of pceTriggersChoiceList
			SendEmptyTLV (str): optional regex of sendEmptyTLV
			SetupPriority (str): optional regex of setupPriority
			SrpId (str): optional regex of srpId
			Tc (str): optional regex of tc
			Ttl (str): optional regex of ttl

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def SendPcUpdate(self, *args, **kwargs):
		"""Executes the sendPcUpdate operation on the server.

		Counts property changes created by the user.

		sendPcUpdate(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the learned information corresponding to trigger data.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendPcUpdate', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class CrpRange(Base):
	"""The CrpRange class encapsulates a user managed crpRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the CrpRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'crpRange'

	def __init__(self, parent):
		super(CrpRange, self).__init__(parent)

	@property
	def AdvertisementHoldTime(self):
		"""The time interval (in seconds) between two consecutive Candidate RP advertisements.

		Returns:
			number
		"""
		return self._get_attribute('advertisementHoldTime')
	@AdvertisementHoldTime.setter
	def AdvertisementHoldTime(self, value):
		self._set_attribute('advertisementHoldTime', value)

	@property
	def BackOffInterval(self):
		"""The back off time interval for the C-RP-Adv messages.

		Returns:
			number
		"""
		return self._get_attribute('backOffInterval')
	@BackOffInterval.setter
	def BackOffInterval(self, value):
		self._set_attribute('backOffInterval', value)

	@property
	def CrpAddress(self):
		"""Start address of the set of candidate RPs to be simulated.

		Returns:
			str
		"""
		return self._get_attribute('crpAddress')
	@CrpAddress.setter
	def CrpAddress(self, value):
		self._set_attribute('crpAddress', value)

	@property
	def Enabled(self):
		"""Enables/disables a Candidate RP range on the fly. The default is disabled.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def GroupAddress(self):
		"""Starting group address of the group range for which the candidate RP will advertise candidacy.

		Returns:
			str
		"""
		return self._get_attribute('groupAddress')
	@GroupAddress.setter
	def GroupAddress(self, value):
		self._set_attribute('groupAddress', value)

	@property
	def GroupCount(self):
		"""Number of groups in the range.

		Returns:
			number
		"""
		return self._get_attribute('groupCount')
	@GroupCount.setter
	def GroupCount(self, value):
		self._set_attribute('groupCount', value)

	@property
	def GroupMaskLen(self):
		"""Mask width (prefix length in bits) for the group range.

		Returns:
			number
		"""
		return self._get_attribute('groupMaskLen')
	@GroupMaskLen.setter
	def GroupMaskLen(self, value):
		self._set_attribute('groupMaskLen', value)

	@property
	def MeshingType(self):
		"""It indicates if the mappings for groups and RP addresses are Fully-Meshed or One-To-One.

		Returns:
			str(fullyMeshed|oneToOne)
		"""
		return self._get_attribute('meshingType')
	@MeshingType.setter
	def MeshingType(self, value):
		self._set_attribute('meshingType', value)

	@property
	def PeriodicAdvertisementInterval(self):
		"""Rate controlling variable indicating how many C-RP-Adv messages can be sent in the specified time interval.

		Returns:
			number
		"""
		return self._get_attribute('periodicAdvertisementInterval')
	@PeriodicAdvertisementInterval.setter
	def PeriodicAdvertisementInterval(self, value):
		self._set_attribute('periodicAdvertisementInterval', value)

	@property
	def PriorityChangeInterval(self):
		"""Time interval after which priority of all the RPs get changed, if priority type is incremental or random.

		Returns:
			number
		"""
		return self._get_attribute('priorityChangeInterval')
	@PriorityChangeInterval.setter
	def PriorityChangeInterval(self, value):
		self._set_attribute('priorityChangeInterval', value)

	@property
	def PriorityType(self):
		"""It indicates the type of priority to be held by the candidate RPs (CRPs). The options are Same, Incremental, and Random.

		Returns:
			str(same|incremental|random)
		"""
		return self._get_attribute('priorityType')
	@PriorityType.setter
	def PriorityType(self, value):
		self._set_attribute('priorityType', value)

	@property
	def PriorityValue(self):
		"""Value of priority field sent in candidate RP advertisement messages.

		Returns:
			number
		"""
		return self._get_attribute('priorityValue')
	@PriorityValue.setter
	def PriorityValue(self, value):
		self._set_attribute('priorityValue', value)

	@property
	def RouterCount(self):
		"""Total number of candidate RPs to be simulated starting from C-RP Address. A contiguous address range is used for this RP range simulation.

		Returns:
			number
		"""
		return self._get_attribute('routerCount')
	@RouterCount.setter
	def RouterCount(self, value):
		self._set_attribute('routerCount', value)

	@property
	def TriggeredCrpMessageCount(self):
		"""The number of times CRP advertisements is sent to the newly elected Bootstrap Router.

		Returns:
			number
		"""
		return self._get_attribute('triggeredCrpMessageCount')
	@TriggeredCrpMessageCount.setter
	def TriggeredCrpMessageCount(self, value):
		self._set_attribute('triggeredCrpMessageCount', value)

	def update(self, AdvertisementHoldTime=None, BackOffInterval=None, CrpAddress=None, Enabled=None, GroupAddress=None, GroupCount=None, GroupMaskLen=None, MeshingType=None, PeriodicAdvertisementInterval=None, PriorityChangeInterval=None, PriorityType=None, PriorityValue=None, RouterCount=None, TriggeredCrpMessageCount=None):
		"""Updates a child instance of crpRange on the server.

		Args:
			AdvertisementHoldTime (number): The time interval (in seconds) between two consecutive Candidate RP advertisements.
			BackOffInterval (number): The back off time interval for the C-RP-Adv messages.
			CrpAddress (str): Start address of the set of candidate RPs to be simulated.
			Enabled (bool): Enables/disables a Candidate RP range on the fly. The default is disabled.
			GroupAddress (str): Starting group address of the group range for which the candidate RP will advertise candidacy.
			GroupCount (number): Number of groups in the range.
			GroupMaskLen (number): Mask width (prefix length in bits) for the group range.
			MeshingType (str(fullyMeshed|oneToOne)): It indicates if the mappings for groups and RP addresses are Fully-Meshed or One-To-One.
			PeriodicAdvertisementInterval (number): Rate controlling variable indicating how many C-RP-Adv messages can be sent in the specified time interval.
			PriorityChangeInterval (number): Time interval after which priority of all the RPs get changed, if priority type is incremental or random.
			PriorityType (str(same|incremental|random)): It indicates the type of priority to be held by the candidate RPs (CRPs). The options are Same, Incremental, and Random.
			PriorityValue (number): Value of priority field sent in candidate RP advertisement messages.
			RouterCount (number): Total number of candidate RPs to be simulated starting from C-RP Address. A contiguous address range is used for this RP range simulation.
			TriggeredCrpMessageCount (number): The number of times CRP advertisements is sent to the newly elected Bootstrap Router.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, AdvertisementHoldTime=None, BackOffInterval=None, CrpAddress=None, Enabled=None, GroupAddress=None, GroupCount=None, GroupMaskLen=None, MeshingType=None, PeriodicAdvertisementInterval=None, PriorityChangeInterval=None, PriorityType=None, PriorityValue=None, RouterCount=None, TriggeredCrpMessageCount=None):
		"""Adds a new crpRange node on the server and retrieves it in this instance.

		Args:
			AdvertisementHoldTime (number): The time interval (in seconds) between two consecutive Candidate RP advertisements.
			BackOffInterval (number): The back off time interval for the C-RP-Adv messages.
			CrpAddress (str): Start address of the set of candidate RPs to be simulated.
			Enabled (bool): Enables/disables a Candidate RP range on the fly. The default is disabled.
			GroupAddress (str): Starting group address of the group range for which the candidate RP will advertise candidacy.
			GroupCount (number): Number of groups in the range.
			GroupMaskLen (number): Mask width (prefix length in bits) for the group range.
			MeshingType (str(fullyMeshed|oneToOne)): It indicates if the mappings for groups and RP addresses are Fully-Meshed or One-To-One.
			PeriodicAdvertisementInterval (number): Rate controlling variable indicating how many C-RP-Adv messages can be sent in the specified time interval.
			PriorityChangeInterval (number): Time interval after which priority of all the RPs get changed, if priority type is incremental or random.
			PriorityType (str(same|incremental|random)): It indicates the type of priority to be held by the candidate RPs (CRPs). The options are Same, Incremental, and Random.
			PriorityValue (number): Value of priority field sent in candidate RP advertisement messages.
			RouterCount (number): Total number of candidate RPs to be simulated starting from C-RP Address. A contiguous address range is used for this RP range simulation.
			TriggeredCrpMessageCount (number): The number of times CRP advertisements is sent to the newly elected Bootstrap Router.

		Returns:
			self: This instance with all currently retrieved crpRange data using find and the newly added crpRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the crpRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, AdvertisementHoldTime=None, BackOffInterval=None, CrpAddress=None, Enabled=None, GroupAddress=None, GroupCount=None, GroupMaskLen=None, MeshingType=None, PeriodicAdvertisementInterval=None, PriorityChangeInterval=None, PriorityType=None, PriorityValue=None, RouterCount=None, TriggeredCrpMessageCount=None):
		"""Finds and retrieves crpRange data from the server.

		All named parameters support regex and can be used to selectively retrieve crpRange data from the server.
		By default the find method takes no parameters and will retrieve all crpRange data from the server.

		Args:
			AdvertisementHoldTime (number): The time interval (in seconds) between two consecutive Candidate RP advertisements.
			BackOffInterval (number): The back off time interval for the C-RP-Adv messages.
			CrpAddress (str): Start address of the set of candidate RPs to be simulated.
			Enabled (bool): Enables/disables a Candidate RP range on the fly. The default is disabled.
			GroupAddress (str): Starting group address of the group range for which the candidate RP will advertise candidacy.
			GroupCount (number): Number of groups in the range.
			GroupMaskLen (number): Mask width (prefix length in bits) for the group range.
			MeshingType (str(fullyMeshed|oneToOne)): It indicates if the mappings for groups and RP addresses are Fully-Meshed or One-To-One.
			PeriodicAdvertisementInterval (number): Rate controlling variable indicating how many C-RP-Adv messages can be sent in the specified time interval.
			PriorityChangeInterval (number): Time interval after which priority of all the RPs get changed, if priority type is incremental or random.
			PriorityType (str(same|incremental|random)): It indicates the type of priority to be held by the candidate RPs (CRPs). The options are Same, Incremental, and Random.
			PriorityValue (number): Value of priority field sent in candidate RP advertisement messages.
			RouterCount (number): Total number of candidate RPs to be simulated starting from C-RP Address. A contiguous address range is used for this RP range simulation.
			TriggeredCrpMessageCount (number): The number of times CRP advertisements is sent to the newly elected Bootstrap Router.

		Returns:
			self: This instance with matching crpRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of crpRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the crpRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class L2VcRange(Base):
	"""The L2VcRange class encapsulates a user managed l2VcRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the L2VcRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'l2VcRange'

	def __init__(self, parent):
		super(L2VcRange, self).__init__(parent)

	@property
	def L2MacVlanRange(self):
		"""An instance of the L2MacVlanRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.l2interface.l2vcrange.l2macvlanrange.l2macvlanrange.L2MacVlanRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.l2interface.l2vcrange.l2macvlanrange.l2macvlanrange import L2MacVlanRange
		return L2MacVlanRange(self)._select()

	@property
	def L2VcIpRange(self):
		"""An instance of the L2VcIpRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.l2interface.l2vcrange.l2vciprange.l2vciprange.L2VcIpRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.l2interface.l2vcrange.l2vciprange.l2vciprange import L2VcIpRange
		return L2VcIpRange(self)._select()

	@property
	def CapableOfReassembly(self):
		"""If enabled, makes the interface capable of reassembly.

		Returns:
			bool
		"""
		return self._get_attribute('capableOfReassembly')
	@CapableOfReassembly.setter
	def CapableOfReassembly(self, value):
		self._set_attribute('capableOfReassembly', value)

	@property
	def Cas(self):
		"""It signifies the CAS value.

		Returns:
			str(e1Trunk|t1EsfTrunk|t1SfTrunk)
		"""
		return self._get_attribute('cas')
	@Cas.setter
	def Cas(self, value):
		self._set_attribute('cas', value)

	@property
	def CeIpAddress(self):
		"""The IP address of attached CE endpoint. If IP Type is set to Ipv4, then the default is 0.0.0.0, and if the IP type is set to Ipv6, then the default is 0:0:0:0:0:0:0:0.

		Returns:
			str
		"""
		return self._get_attribute('ceIpAddress')
	@CeIpAddress.setter
	def CeIpAddress(self, value):
		self._set_attribute('ceIpAddress', value)

	@property
	def CemOption(self):
		"""The value of the CEM option.

		Returns:
			number
		"""
		return self._get_attribute('cemOption')
	@CemOption.setter
	def CemOption(self, value):
		self._set_attribute('cemOption', value)

	@property
	def CemPayload(self):
		"""If enabled, indicates that there is a Circuit Emulation Service over MPLS (CEM) payload.

		Returns:
			number
		"""
		return self._get_attribute('cemPayload')
	@CemPayload.setter
	def CemPayload(self, value):
		self._set_attribute('cemPayload', value)

	@property
	def Count(self):
		"""(In octets) The 8-bit VC information Length field. It indicates the length of the (2-octet) VC ID field plus combined length of all of the parameters in the VC FEC element.

		Returns:
			number
		"""
		return self._get_attribute('count')
	@Count.setter
	def Count(self, value):
		self._set_attribute('count', value)

	@property
	def Description(self):
		"""An optional user-defined interface description. It may be used with ALL VC types. Valid length is 0 to 80 octets.

		Returns:
			str
		"""
		return self._get_attribute('description')
	@Description.setter
	def Description(self, value):
		self._set_attribute('description', value)

	@property
	def DoNotExpandIntoVcs(self):
		"""If true, the VC ranges do not expand into individual VCs.

		Returns:
			bool
		"""
		return self._get_attribute('doNotExpandIntoVcs')
	@DoNotExpandIntoVcs.setter
	def DoNotExpandIntoVcs(self, value):
		self._set_attribute('doNotExpandIntoVcs', value)

	@property
	def DownInterval(self):
		"""Time interval for which the PW status will remain down. (Default= 60 seconds)

		Returns:
			number
		"""
		return self._get_attribute('downInterval')
	@DownInterval.setter
	def DownInterval(self, value):
		self._set_attribute('downInterval', value)

	@property
	def DownStartInterval(self):
		"""The duration in time after session becomes up and a notification message being sent to make the session down. (Default= 30 seconds)

		Returns:
			number
		"""
		return self._get_attribute('downStartInterval')
	@DownStartInterval.setter
	def DownStartInterval(self, value):
		self._set_attribute('downStartInterval', value)

	@property
	def EnableBfdIpUdpCv(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableBfdIpUdpCv')
	@EnableBfdIpUdpCv.setter
	def EnableBfdIpUdpCv(self, value):
		self._set_attribute('enableBfdIpUdpCv', value)

	@property
	def EnableBfdPwAchCv(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableBfdPwAchCv')
	@EnableBfdPwAchCv.setter
	def EnableBfdPwAchCv(self, value):
		self._set_attribute('enableBfdPwAchCv', value)

	@property
	def EnableCBit(self):
		"""Controls generation of the control word.

		Returns:
			bool
		"""
		return self._get_attribute('enableCBit')
	@EnableCBit.setter
	def EnableCBit(self, value):
		self._set_attribute('enableCBit', value)

	@property
	def EnableCccvNegotiation(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableCccvNegotiation')
	@EnableCccvNegotiation.setter
	def EnableCccvNegotiation(self, value):
		self._set_attribute('enableCccvNegotiation', value)

	@property
	def EnableCemOption(self):
		"""Enable the Circuit Emulation over MPLS option, for encapsulation of TDM signals.

		Returns:
			bool
		"""
		return self._get_attribute('enableCemOption')
	@EnableCemOption.setter
	def EnableCemOption(self, value):
		self._set_attribute('enableCemOption', value)

	@property
	def EnableCemPayload(self):
		"""Enable the Circuit Emulation over MPLS payload.

		Returns:
			bool
		"""
		return self._get_attribute('enableCemPayload')
	@EnableCemPayload.setter
	def EnableCemPayload(self, value):
		self._set_attribute('enableCemPayload', value)

	@property
	def EnableDescriptionPresent(self):
		"""If enabled, indicates that an optional interface description is present.

		Returns:
			bool
		"""
		return self._get_attribute('enableDescriptionPresent')
	@EnableDescriptionPresent.setter
	def EnableDescriptionPresent(self, value):
		self._set_attribute('enableDescriptionPresent', value)

	@property
	def EnableLspPingCv(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableLspPingCv')
	@EnableLspPingCv.setter
	def EnableLspPingCv(self, value):
		self._set_attribute('enableLspPingCv', value)

	@property
	def EnableMaxAtmPresent(self):
		"""Enables the generation of an interface parameter field with the maximum number of concatenated ATM cells. (default = 0)

		Returns:
			bool
		"""
		return self._get_attribute('enableMaxAtmPresent')
	@EnableMaxAtmPresent.setter
	def EnableMaxAtmPresent(self, value):
		self._set_attribute('enableMaxAtmPresent', value)

	@property
	def EnableMtuPresent(self):
		"""This attribute enables the generation of an MTU interface parameter field.

		Returns:
			bool
		"""
		return self._get_attribute('enableMtuPresent')
	@EnableMtuPresent.setter
	def EnableMtuPresent(self, value):
		self._set_attribute('enableMtuPresent', value)

	@property
	def EnablePacking(self):
		"""(For L2 VC FEC ranges and in Unsolicited Label Distribution Mode ONLY.) If enabled, L2 VC FEC ranges will be aggregated within a single LDP PDU to conserve bandwidth and processing.

		Returns:
			bool
		"""
		return self._get_attribute('enablePacking')
	@EnablePacking.setter
	def EnablePacking(self, value):
		self._set_attribute('enablePacking', value)

	@property
	def EnablePwAchCc(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enablePwAchCc')
	@EnablePwAchCc.setter
	def EnablePwAchCc(self, value):
		self._set_attribute('enablePwAchCc', value)

	@property
	def EnablePwStatusTlv(self):
		"""If checked, this enables the use of PW status TLV in notification messages to notify the PW status.

		Returns:
			bool
		"""
		return self._get_attribute('enablePwStatusTlv')
	@EnablePwStatusTlv.setter
	def EnablePwStatusTlv(self, value):
		self._set_attribute('enablePwStatusTlv', value)

	@property
	def EnableRouterAlertCc(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableRouterAlertCc')
	@EnableRouterAlertCc.setter
	def EnableRouterAlertCc(self, value):
		self._set_attribute('enableRouterAlertCc', value)

	@property
	def Enabled(self):
		"""Enables use of this VC range.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def FecType(self):
		"""The FEC type. The options are: PW Id FEC 0x80, Generalized Id FEC 0x81 VPLS.

		Returns:
			str(pwIdFec|generalizedIdFecVpls)
		"""
		return self._get_attribute('fecType')
	@FecType.setter
	def FecType(self, value):
		self._set_attribute('fecType', value)

	@property
	def Frequency(self):
		"""It is the frequency.

		Returns:
			number
		"""
		return self._get_attribute('frequency')
	@Frequency.setter
	def Frequency(self, value):
		self._set_attribute('frequency', value)

	@property
	def IncludeRtpHeader(self):
		"""If true, includes the RTP header.

		Returns:
			bool
		"""
		return self._get_attribute('includeRtpHeader')
	@IncludeRtpHeader.setter
	def IncludeRtpHeader(self, value):
		self._set_attribute('includeRtpHeader', value)

	@property
	def IncludeSsrc(self):
		"""If true, enables SSRC.

		Returns:
			bool
		"""
		return self._get_attribute('includeSsrc')
	@IncludeSsrc.setter
	def IncludeSsrc(self, value):
		self._set_attribute('includeSsrc', value)

	@property
	def IncludeTdmBitrate(self):
		"""If true, enables TDM bit rate.

		Returns:
			bool
		"""
		return self._get_attribute('includeTdmBitrate')
	@IncludeTdmBitrate.setter
	def IncludeTdmBitrate(self, value):
		self._set_attribute('includeTdmBitrate', value)

	@property
	def IncludeTdmOption(self):
		"""If true, includes the TDM option.

		Returns:
			bool
		"""
		return self._get_attribute('includeTdmOption')
	@IncludeTdmOption.setter
	def IncludeTdmOption(self, value):
		self._set_attribute('includeTdmOption', value)

	@property
	def IncludeTdmPayload(self):
		"""If true, enables TDM payload.

		Returns:
			bool
		"""
		return self._get_attribute('includeTdmPayload')
	@IncludeTdmPayload.setter
	def IncludeTdmPayload(self, value):
		self._set_attribute('includeTdmPayload', value)

	@property
	def IpType(self):
		"""The type (IPv4 or IPv6) of the neighbor.

		Returns:
			number
		"""
		return self._get_attribute('ipType')
	@IpType.setter
	def IpType(self, value):
		self._set_attribute('ipType', value)

	@property
	def LabelMode(self):
		"""Indicates whether the same label or incrementing labels should be used in the VC ranges.

		Returns:
			str(none|increment)
		"""
		return self._get_attribute('labelMode')
	@LabelMode.setter
	def LabelMode(self, value):
		self._set_attribute('labelMode', value)

	@property
	def LabelStart(self):
		"""The first label in the range of labels. The default is 16.

		Returns:
			number
		"""
		return self._get_attribute('labelStart')
	@LabelStart.setter
	def LabelStart(self, value):
		self._set_attribute('labelStart', value)

	@property
	def MaxNumberOfAtmCells(self):
		"""The maximum number of ATM cells which may be concatenated and sent in a single MPLS frame. This parameter is part of the FEC element.

		Returns:
			number
		"""
		return self._get_attribute('maxNumberOfAtmCells')
	@MaxNumberOfAtmCells.setter
	def MaxNumberOfAtmCells(self, value):
		self._set_attribute('maxNumberOfAtmCells', value)

	@property
	def Mtu(self):
		"""(in octets) The 2-octet value for the maximum Transmission Unit (MTU).

		Returns:
			number
		"""
		return self._get_attribute('mtu')
	@Mtu.setter
	def Mtu(self, value):
		self._set_attribute('mtu', value)

	@property
	def PayloadType(self):
		"""It is the payload type.

		Returns:
			number
		"""
		return self._get_attribute('payloadType')
	@PayloadType.setter
	def PayloadType(self, value):
		self._set_attribute('payloadType', value)

	@property
	def PeerAddress(self):
		"""The IPv4 address of the LDP router which is the peer for this VC range.

		Returns:
			str
		"""
		return self._get_attribute('peerAddress')
	@PeerAddress.setter
	def PeerAddress(self, value):
		self._set_attribute('peerAddress', value)

	@property
	def ProvisioningModel(self):
		"""Editable dropdown to denote the Provisioning Model.

		Returns:
			str(manualConfiguration|bgpAutoDiscovery)
		"""
		return self._get_attribute('provisioningModel')
	@ProvisioningModel.setter
	def ProvisioningModel(self, value):
		self._set_attribute('provisioningModel', value)

	@property
	def PwStatusCode(self):
		"""This is an editable dropdown to denote the PW status. This field is editable. The range is from 0x00000001 - 0xFFFFFFFF.

		Returns:
			number
		"""
		return self._get_attribute('pwStatusCode')
	@PwStatusCode.setter
	def PwStatusCode(self, value):
		self._set_attribute('pwStatusCode', value)

	@property
	def RepeatCount(self):
		"""The number of times to repeat the above processes. The default is 1.

		Returns:
			number
		"""
		return self._get_attribute('repeatCount')
	@RepeatCount.setter
	def RepeatCount(self, value):
		self._set_attribute('repeatCount', value)

	@property
	def SendPwStatus(self):
		"""If checked, it signifies whether to send a notification message with a PW status for the corresponding PW.

		Returns:
			bool
		"""
		return self._get_attribute('sendPwStatus')
	@SendPwStatus.setter
	def SendPwStatus(self, value):
		self._set_attribute('sendPwStatus', value)

	@property
	def SourceAiiAsIp(self):
		"""The IP address.

		Returns:
			str
		"""
		return self._get_attribute('sourceAiiAsIp')
	@SourceAiiAsIp.setter
	def SourceAiiAsIp(self, value):
		self._set_attribute('sourceAiiAsIp', value)

	@property
	def SourceAiiAsNumber(self):
		"""The numerical value indicating the AS of the Source AII.

		Returns:
			number
		"""
		return self._get_attribute('sourceAiiAsNumber')
	@SourceAiiAsNumber.setter
	def SourceAiiAsNumber(self, value):
		self._set_attribute('sourceAiiAsNumber', value)

	@property
	def SourceAiiType(self):
		"""Editable dropdown. The options are: AS, IP.

		Returns:
			str(number|ipAddress)
		"""
		return self._get_attribute('sourceAiiType')
	@SourceAiiType.setter
	def SourceAiiType(self, value):
		self._set_attribute('sourceAiiType', value)

	@property
	def Sp(self):
		"""It signifies the SP value.

		Returns:
			str(hexVal0|hexVal1|hexVal2|hexVal3)
		"""
		return self._get_attribute('sp')
	@Sp.setter
	def Sp(self, value):
		self._set_attribute('sp', value)

	@property
	def Ssrc(self):
		"""Indicates the SSRC value.

		Returns:
			number
		"""
		return self._get_attribute('ssrc')
	@Ssrc.setter
	def Ssrc(self, value):
		self._set_attribute('ssrc', value)

	@property
	def Step(self):
		"""The number to increment the peer address by.

		Returns:
			number
		"""
		return self._get_attribute('step')
	@Step.setter
	def Step(self, value):
		self._set_attribute('step', value)

	@property
	def TargetAiiAsIp(self):
		"""The IP address of the Target AII.

		Returns:
			str
		"""
		return self._get_attribute('targetAiiAsIp')
	@TargetAiiAsIp.setter
	def TargetAiiAsIp(self, value):
		self._set_attribute('targetAiiAsIp', value)

	@property
	def TargetAiiAsNumber(self):
		"""The numerical value of the Target AII.

		Returns:
			number
		"""
		return self._get_attribute('targetAiiAsNumber')
	@TargetAiiAsNumber.setter
	def TargetAiiAsNumber(self, value):
		self._set_attribute('targetAiiAsNumber', value)

	@property
	def TargetAiiType(self):
		"""Editable dropdown. The options are: AS, IP.

		Returns:
			str(number|ipAddress)
		"""
		return self._get_attribute('targetAiiType')
	@TargetAiiType.setter
	def TargetAiiType(self, value):
		self._set_attribute('targetAiiType', value)

	@property
	def TdmBitrate(self):
		"""The tdm bit rate.

		Returns:
			number
		"""
		return self._get_attribute('tdmBitrate')
	@TdmBitrate.setter
	def TdmBitrate(self, value):
		self._set_attribute('tdmBitrate', value)

	@property
	def TdmDataSize(self):
		"""Indicates the TDM data size.

		Returns:
			number
		"""
		return self._get_attribute('tdmDataSize')
	@TdmDataSize.setter
	def TdmDataSize(self, value):
		self._set_attribute('tdmDataSize', value)

	@property
	def TimestampMode(self):
		"""The time stamp mode.

		Returns:
			str(absolute|differential)
		"""
		return self._get_attribute('timestampMode')
	@TimestampMode.setter
	def TimestampMode(self, value):
		self._set_attribute('timestampMode', value)

	@property
	def UpInterval(self):
		"""Time interval for which the same process to be repeated. (Default = 30 sec)

		Returns:
			number
		"""
		return self._get_attribute('upInterval')
	@UpInterval.setter
	def UpInterval(self, value):
		self._set_attribute('upInterval', value)

	@property
	def VcId(self):
		"""The 32-bit VC connection identifier. Used with the VC type to identify a specific VC (for VC types 0x0001 to 0x000B).

		Returns:
			number
		"""
		return self._get_attribute('vcId')
	@VcId.setter
	def VcId(self, value):
		self._set_attribute('vcId', value)

	@property
	def VcIdStep(self):
		"""The increment step to be added to each additional VC ID in the range of VC IDs.

		Returns:
			number
		"""
		return self._get_attribute('vcIdStep')
	@VcIdStep.setter
	def VcIdStep(self, value):
		self._set_attribute('vcIdStep', value)

	@property
	def VplsIdAsNumber(self):
		"""The 2 byte unsigned integer value indicating the VPLS ID AS Number.

		Returns:
			number
		"""
		return self._get_attribute('vplsIdAsNumber')
	@VplsIdAsNumber.setter
	def VplsIdAsNumber(self, value):
		self._set_attribute('vplsIdAsNumber', value)

	@property
	def VplsIdAsNumberStep(self):
		"""The 2 byte unsigned integer value indicating the VPLS ID AS Number Step.

		Returns:
			number
		"""
		return self._get_attribute('vplsIdAsNumberStep')
	@VplsIdAsNumberStep.setter
	def VplsIdAsNumberStep(self, value):
		self._set_attribute('vplsIdAsNumberStep', value)

	@property
	def VplsIdAssignedNumber(self):
		"""The 2 or 4 byte unsigned integer value dependent on the vplsIdType

		Returns:
			number
		"""
		return self._get_attribute('vplsIdAssignedNumber')
	@VplsIdAssignedNumber.setter
	def VplsIdAssignedNumber(self, value):
		self._set_attribute('vplsIdAssignedNumber', value)

	@property
	def VplsIdAssignedNumberStep(self):
		"""The 2 or 4 byte unsigned integer value dependent on the vplsIdType.

		Returns:
			number
		"""
		return self._get_attribute('vplsIdAssignedNumberStep')
	@VplsIdAssignedNumberStep.setter
	def VplsIdAssignedNumberStep(self, value):
		self._set_attribute('vplsIdAssignedNumberStep', value)

	@property
	def VplsIdCount(self):
		"""The 4 byte unsigned integer indicating the VPLS ID Count.

		Returns:
			number
		"""
		return self._get_attribute('vplsIdCount')
	@VplsIdCount.setter
	def VplsIdCount(self, value):
		self._set_attribute('vplsIdCount', value)

	@property
	def VplsIdIpAddress(self):
		"""The IP address of the VPLS Id.

		Returns:
			str
		"""
		return self._get_attribute('vplsIdIpAddress')
	@VplsIdIpAddress.setter
	def VplsIdIpAddress(self, value):
		self._set_attribute('vplsIdIpAddress', value)

	@property
	def VplsIdIpAddressStep(self):
		"""The IP address of the VPLS Id.

		Returns:
			str
		"""
		return self._get_attribute('vplsIdIpAddressStep')
	@VplsIdIpAddressStep.setter
	def VplsIdIpAddressStep(self, value):
		self._set_attribute('vplsIdIpAddressStep', value)

	@property
	def VplsIdType(self):
		"""Editable dropdown. The options are: AS, IP.

		Returns:
			str(asNumber|ipAddress)
		"""
		return self._get_attribute('vplsIdType')
	@VplsIdType.setter
	def VplsIdType(self, value):
		self._set_attribute('vplsIdType', value)

	def update(self, CapableOfReassembly=None, Cas=None, CeIpAddress=None, CemOption=None, CemPayload=None, Count=None, Description=None, DoNotExpandIntoVcs=None, DownInterval=None, DownStartInterval=None, EnableBfdIpUdpCv=None, EnableBfdPwAchCv=None, EnableCBit=None, EnableCccvNegotiation=None, EnableCemOption=None, EnableCemPayload=None, EnableDescriptionPresent=None, EnableLspPingCv=None, EnableMaxAtmPresent=None, EnableMtuPresent=None, EnablePacking=None, EnablePwAchCc=None, EnablePwStatusTlv=None, EnableRouterAlertCc=None, Enabled=None, FecType=None, Frequency=None, IncludeRtpHeader=None, IncludeSsrc=None, IncludeTdmBitrate=None, IncludeTdmOption=None, IncludeTdmPayload=None, IpType=None, LabelMode=None, LabelStart=None, MaxNumberOfAtmCells=None, Mtu=None, PayloadType=None, PeerAddress=None, ProvisioningModel=None, PwStatusCode=None, RepeatCount=None, SendPwStatus=None, SourceAiiAsIp=None, SourceAiiAsNumber=None, SourceAiiType=None, Sp=None, Ssrc=None, Step=None, TargetAiiAsIp=None, TargetAiiAsNumber=None, TargetAiiType=None, TdmBitrate=None, TdmDataSize=None, TimestampMode=None, UpInterval=None, VcId=None, VcIdStep=None, VplsIdAsNumber=None, VplsIdAsNumberStep=None, VplsIdAssignedNumber=None, VplsIdAssignedNumberStep=None, VplsIdCount=None, VplsIdIpAddress=None, VplsIdIpAddressStep=None, VplsIdType=None):
		"""Updates a child instance of l2VcRange on the server.

		Args:
			CapableOfReassembly (bool): If enabled, makes the interface capable of reassembly.
			Cas (str(e1Trunk|t1EsfTrunk|t1SfTrunk)): It signifies the CAS value.
			CeIpAddress (str): The IP address of attached CE endpoint. If IP Type is set to Ipv4, then the default is 0.0.0.0, and if the IP type is set to Ipv6, then the default is 0:0:0:0:0:0:0:0.
			CemOption (number): The value of the CEM option.
			CemPayload (number): If enabled, indicates that there is a Circuit Emulation Service over MPLS (CEM) payload.
			Count (number): (In octets) The 8-bit VC information Length field. It indicates the length of the (2-octet) VC ID field plus combined length of all of the parameters in the VC FEC element.
			Description (str): An optional user-defined interface description. It may be used with ALL VC types. Valid length is 0 to 80 octets.
			DoNotExpandIntoVcs (bool): If true, the VC ranges do not expand into individual VCs.
			DownInterval (number): Time interval for which the PW status will remain down. (Default= 60 seconds)
			DownStartInterval (number): The duration in time after session becomes up and a notification message being sent to make the session down. (Default= 30 seconds)
			EnableBfdIpUdpCv (bool): NOT DEFINED
			EnableBfdPwAchCv (bool): NOT DEFINED
			EnableCBit (bool): Controls generation of the control word.
			EnableCccvNegotiation (bool): NOT DEFINED
			EnableCemOption (bool): Enable the Circuit Emulation over MPLS option, for encapsulation of TDM signals.
			EnableCemPayload (bool): Enable the Circuit Emulation over MPLS payload.
			EnableDescriptionPresent (bool): If enabled, indicates that an optional interface description is present.
			EnableLspPingCv (bool): NOT DEFINED
			EnableMaxAtmPresent (bool): Enables the generation of an interface parameter field with the maximum number of concatenated ATM cells. (default = 0)
			EnableMtuPresent (bool): This attribute enables the generation of an MTU interface parameter field.
			EnablePacking (bool): (For L2 VC FEC ranges and in Unsolicited Label Distribution Mode ONLY.) If enabled, L2 VC FEC ranges will be aggregated within a single LDP PDU to conserve bandwidth and processing.
			EnablePwAchCc (bool): NOT DEFINED
			EnablePwStatusTlv (bool): If checked, this enables the use of PW status TLV in notification messages to notify the PW status.
			EnableRouterAlertCc (bool): NOT DEFINED
			Enabled (bool): Enables use of this VC range.
			FecType (str(pwIdFec|generalizedIdFecVpls)): The FEC type. The options are: PW Id FEC 0x80, Generalized Id FEC 0x81 VPLS.
			Frequency (number): It is the frequency.
			IncludeRtpHeader (bool): If true, includes the RTP header.
			IncludeSsrc (bool): If true, enables SSRC.
			IncludeTdmBitrate (bool): If true, enables TDM bit rate.
			IncludeTdmOption (bool): If true, includes the TDM option.
			IncludeTdmPayload (bool): If true, enables TDM payload.
			IpType (number): The type (IPv4 or IPv6) of the neighbor.
			LabelMode (str(none|increment)): Indicates whether the same label or incrementing labels should be used in the VC ranges.
			LabelStart (number): The first label in the range of labels. The default is 16.
			MaxNumberOfAtmCells (number): The maximum number of ATM cells which may be concatenated and sent in a single MPLS frame. This parameter is part of the FEC element.
			Mtu (number): (in octets) The 2-octet value for the maximum Transmission Unit (MTU).
			PayloadType (number): It is the payload type.
			PeerAddress (str): The IPv4 address of the LDP router which is the peer for this VC range.
			ProvisioningModel (str(manualConfiguration|bgpAutoDiscovery)): Editable dropdown to denote the Provisioning Model.
			PwStatusCode (number): This is an editable dropdown to denote the PW status. This field is editable. The range is from 0x00000001 - 0xFFFFFFFF.
			RepeatCount (number): The number of times to repeat the above processes. The default is 1.
			SendPwStatus (bool): If checked, it signifies whether to send a notification message with a PW status for the corresponding PW.
			SourceAiiAsIp (str): The IP address.
			SourceAiiAsNumber (number): The numerical value indicating the AS of the Source AII.
			SourceAiiType (str(number|ipAddress)): Editable dropdown. The options are: AS, IP.
			Sp (str(hexVal0|hexVal1|hexVal2|hexVal3)): It signifies the SP value.
			Ssrc (number): Indicates the SSRC value.
			Step (number): The number to increment the peer address by.
			TargetAiiAsIp (str): The IP address of the Target AII.
			TargetAiiAsNumber (number): The numerical value of the Target AII.
			TargetAiiType (str(number|ipAddress)): Editable dropdown. The options are: AS, IP.
			TdmBitrate (number): The tdm bit rate.
			TdmDataSize (number): Indicates the TDM data size.
			TimestampMode (str(absolute|differential)): The time stamp mode.
			UpInterval (number): Time interval for which the same process to be repeated. (Default = 30 sec)
			VcId (number): The 32-bit VC connection identifier. Used with the VC type to identify a specific VC (for VC types 0x0001 to 0x000B).
			VcIdStep (number): The increment step to be added to each additional VC ID in the range of VC IDs.
			VplsIdAsNumber (number): The 2 byte unsigned integer value indicating the VPLS ID AS Number.
			VplsIdAsNumberStep (number): The 2 byte unsigned integer value indicating the VPLS ID AS Number Step.
			VplsIdAssignedNumber (number): The 2 or 4 byte unsigned integer value dependent on the vplsIdType
			VplsIdAssignedNumberStep (number): The 2 or 4 byte unsigned integer value dependent on the vplsIdType.
			VplsIdCount (number): The 4 byte unsigned integer indicating the VPLS ID Count.
			VplsIdIpAddress (str): The IP address of the VPLS Id.
			VplsIdIpAddressStep (str): The IP address of the VPLS Id.
			VplsIdType (str(asNumber|ipAddress)): Editable dropdown. The options are: AS, IP.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, CapableOfReassembly=None, Cas=None, CeIpAddress=None, CemOption=None, CemPayload=None, Count=None, Description=None, DoNotExpandIntoVcs=None, DownInterval=None, DownStartInterval=None, EnableBfdIpUdpCv=None, EnableBfdPwAchCv=None, EnableCBit=None, EnableCccvNegotiation=None, EnableCemOption=None, EnableCemPayload=None, EnableDescriptionPresent=None, EnableLspPingCv=None, EnableMaxAtmPresent=None, EnableMtuPresent=None, EnablePacking=None, EnablePwAchCc=None, EnablePwStatusTlv=None, EnableRouterAlertCc=None, Enabled=None, FecType=None, Frequency=None, IncludeRtpHeader=None, IncludeSsrc=None, IncludeTdmBitrate=None, IncludeTdmOption=None, IncludeTdmPayload=None, IpType=None, LabelMode=None, LabelStart=None, MaxNumberOfAtmCells=None, Mtu=None, PayloadType=None, PeerAddress=None, ProvisioningModel=None, PwStatusCode=None, RepeatCount=None, SendPwStatus=None, SourceAiiAsIp=None, SourceAiiAsNumber=None, SourceAiiType=None, Sp=None, Ssrc=None, Step=None, TargetAiiAsIp=None, TargetAiiAsNumber=None, TargetAiiType=None, TdmBitrate=None, TdmDataSize=None, TimestampMode=None, UpInterval=None, VcId=None, VcIdStep=None, VplsIdAsNumber=None, VplsIdAsNumberStep=None, VplsIdAssignedNumber=None, VplsIdAssignedNumberStep=None, VplsIdCount=None, VplsIdIpAddress=None, VplsIdIpAddressStep=None, VplsIdType=None):
		"""Adds a new l2VcRange node on the server and retrieves it in this instance.

		Args:
			CapableOfReassembly (bool): If enabled, makes the interface capable of reassembly.
			Cas (str(e1Trunk|t1EsfTrunk|t1SfTrunk)): It signifies the CAS value.
			CeIpAddress (str): The IP address of attached CE endpoint. If IP Type is set to Ipv4, then the default is 0.0.0.0, and if the IP type is set to Ipv6, then the default is 0:0:0:0:0:0:0:0.
			CemOption (number): The value of the CEM option.
			CemPayload (number): If enabled, indicates that there is a Circuit Emulation Service over MPLS (CEM) payload.
			Count (number): (In octets) The 8-bit VC information Length field. It indicates the length of the (2-octet) VC ID field plus combined length of all of the parameters in the VC FEC element.
			Description (str): An optional user-defined interface description. It may be used with ALL VC types. Valid length is 0 to 80 octets.
			DoNotExpandIntoVcs (bool): If true, the VC ranges do not expand into individual VCs.
			DownInterval (number): Time interval for which the PW status will remain down. (Default= 60 seconds)
			DownStartInterval (number): The duration in time after session becomes up and a notification message being sent to make the session down. (Default= 30 seconds)
			EnableBfdIpUdpCv (bool): NOT DEFINED
			EnableBfdPwAchCv (bool): NOT DEFINED
			EnableCBit (bool): Controls generation of the control word.
			EnableCccvNegotiation (bool): NOT DEFINED
			EnableCemOption (bool): Enable the Circuit Emulation over MPLS option, for encapsulation of TDM signals.
			EnableCemPayload (bool): Enable the Circuit Emulation over MPLS payload.
			EnableDescriptionPresent (bool): If enabled, indicates that an optional interface description is present.
			EnableLspPingCv (bool): NOT DEFINED
			EnableMaxAtmPresent (bool): Enables the generation of an interface parameter field with the maximum number of concatenated ATM cells. (default = 0)
			EnableMtuPresent (bool): This attribute enables the generation of an MTU interface parameter field.
			EnablePacking (bool): (For L2 VC FEC ranges and in Unsolicited Label Distribution Mode ONLY.) If enabled, L2 VC FEC ranges will be aggregated within a single LDP PDU to conserve bandwidth and processing.
			EnablePwAchCc (bool): NOT DEFINED
			EnablePwStatusTlv (bool): If checked, this enables the use of PW status TLV in notification messages to notify the PW status.
			EnableRouterAlertCc (bool): NOT DEFINED
			Enabled (bool): Enables use of this VC range.
			FecType (str(pwIdFec|generalizedIdFecVpls)): The FEC type. The options are: PW Id FEC 0x80, Generalized Id FEC 0x81 VPLS.
			Frequency (number): It is the frequency.
			IncludeRtpHeader (bool): If true, includes the RTP header.
			IncludeSsrc (bool): If true, enables SSRC.
			IncludeTdmBitrate (bool): If true, enables TDM bit rate.
			IncludeTdmOption (bool): If true, includes the TDM option.
			IncludeTdmPayload (bool): If true, enables TDM payload.
			IpType (number): The type (IPv4 or IPv6) of the neighbor.
			LabelMode (str(none|increment)): Indicates whether the same label or incrementing labels should be used in the VC ranges.
			LabelStart (number): The first label in the range of labels. The default is 16.
			MaxNumberOfAtmCells (number): The maximum number of ATM cells which may be concatenated and sent in a single MPLS frame. This parameter is part of the FEC element.
			Mtu (number): (in octets) The 2-octet value for the maximum Transmission Unit (MTU).
			PayloadType (number): It is the payload type.
			PeerAddress (str): The IPv4 address of the LDP router which is the peer for this VC range.
			ProvisioningModel (str(manualConfiguration|bgpAutoDiscovery)): Editable dropdown to denote the Provisioning Model.
			PwStatusCode (number): This is an editable dropdown to denote the PW status. This field is editable. The range is from 0x00000001 - 0xFFFFFFFF.
			RepeatCount (number): The number of times to repeat the above processes. The default is 1.
			SendPwStatus (bool): If checked, it signifies whether to send a notification message with a PW status for the corresponding PW.
			SourceAiiAsIp (str): The IP address.
			SourceAiiAsNumber (number): The numerical value indicating the AS of the Source AII.
			SourceAiiType (str(number|ipAddress)): Editable dropdown. The options are: AS, IP.
			Sp (str(hexVal0|hexVal1|hexVal2|hexVal3)): It signifies the SP value.
			Ssrc (number): Indicates the SSRC value.
			Step (number): The number to increment the peer address by.
			TargetAiiAsIp (str): The IP address of the Target AII.
			TargetAiiAsNumber (number): The numerical value of the Target AII.
			TargetAiiType (str(number|ipAddress)): Editable dropdown. The options are: AS, IP.
			TdmBitrate (number): The tdm bit rate.
			TdmDataSize (number): Indicates the TDM data size.
			TimestampMode (str(absolute|differential)): The time stamp mode.
			UpInterval (number): Time interval for which the same process to be repeated. (Default = 30 sec)
			VcId (number): The 32-bit VC connection identifier. Used with the VC type to identify a specific VC (for VC types 0x0001 to 0x000B).
			VcIdStep (number): The increment step to be added to each additional VC ID in the range of VC IDs.
			VplsIdAsNumber (number): The 2 byte unsigned integer value indicating the VPLS ID AS Number.
			VplsIdAsNumberStep (number): The 2 byte unsigned integer value indicating the VPLS ID AS Number Step.
			VplsIdAssignedNumber (number): The 2 or 4 byte unsigned integer value dependent on the vplsIdType
			VplsIdAssignedNumberStep (number): The 2 or 4 byte unsigned integer value dependent on the vplsIdType.
			VplsIdCount (number): The 4 byte unsigned integer indicating the VPLS ID Count.
			VplsIdIpAddress (str): The IP address of the VPLS Id.
			VplsIdIpAddressStep (str): The IP address of the VPLS Id.
			VplsIdType (str(asNumber|ipAddress)): Editable dropdown. The options are: AS, IP.

		Returns:
			self: This instance with all currently retrieved l2VcRange data using find and the newly added l2VcRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the l2VcRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, CapableOfReassembly=None, Cas=None, CeIpAddress=None, CemOption=None, CemPayload=None, Count=None, Description=None, DoNotExpandIntoVcs=None, DownInterval=None, DownStartInterval=None, EnableBfdIpUdpCv=None, EnableBfdPwAchCv=None, EnableCBit=None, EnableCccvNegotiation=None, EnableCemOption=None, EnableCemPayload=None, EnableDescriptionPresent=None, EnableLspPingCv=None, EnableMaxAtmPresent=None, EnableMtuPresent=None, EnablePacking=None, EnablePwAchCc=None, EnablePwStatusTlv=None, EnableRouterAlertCc=None, Enabled=None, FecType=None, Frequency=None, IncludeRtpHeader=None, IncludeSsrc=None, IncludeTdmBitrate=None, IncludeTdmOption=None, IncludeTdmPayload=None, IpType=None, LabelMode=None, LabelStart=None, MaxNumberOfAtmCells=None, Mtu=None, PayloadType=None, PeerAddress=None, ProvisioningModel=None, PwStatusCode=None, RepeatCount=None, SendPwStatus=None, SourceAiiAsIp=None, SourceAiiAsNumber=None, SourceAiiType=None, Sp=None, Ssrc=None, Step=None, TargetAiiAsIp=None, TargetAiiAsNumber=None, TargetAiiType=None, TdmBitrate=None, TdmDataSize=None, TimestampMode=None, UpInterval=None, VcId=None, VcIdStep=None, VplsIdAsNumber=None, VplsIdAsNumberStep=None, VplsIdAssignedNumber=None, VplsIdAssignedNumberStep=None, VplsIdCount=None, VplsIdIpAddress=None, VplsIdIpAddressStep=None, VplsIdType=None):
		"""Finds and retrieves l2VcRange data from the server.

		All named parameters support regex and can be used to selectively retrieve l2VcRange data from the server.
		By default the find method takes no parameters and will retrieve all l2VcRange data from the server.

		Args:
			CapableOfReassembly (bool): If enabled, makes the interface capable of reassembly.
			Cas (str(e1Trunk|t1EsfTrunk|t1SfTrunk)): It signifies the CAS value.
			CeIpAddress (str): The IP address of attached CE endpoint. If IP Type is set to Ipv4, then the default is 0.0.0.0, and if the IP type is set to Ipv6, then the default is 0:0:0:0:0:0:0:0.
			CemOption (number): The value of the CEM option.
			CemPayload (number): If enabled, indicates that there is a Circuit Emulation Service over MPLS (CEM) payload.
			Count (number): (In octets) The 8-bit VC information Length field. It indicates the length of the (2-octet) VC ID field plus combined length of all of the parameters in the VC FEC element.
			Description (str): An optional user-defined interface description. It may be used with ALL VC types. Valid length is 0 to 80 octets.
			DoNotExpandIntoVcs (bool): If true, the VC ranges do not expand into individual VCs.
			DownInterval (number): Time interval for which the PW status will remain down. (Default= 60 seconds)
			DownStartInterval (number): The duration in time after session becomes up and a notification message being sent to make the session down. (Default= 30 seconds)
			EnableBfdIpUdpCv (bool): NOT DEFINED
			EnableBfdPwAchCv (bool): NOT DEFINED
			EnableCBit (bool): Controls generation of the control word.
			EnableCccvNegotiation (bool): NOT DEFINED
			EnableCemOption (bool): Enable the Circuit Emulation over MPLS option, for encapsulation of TDM signals.
			EnableCemPayload (bool): Enable the Circuit Emulation over MPLS payload.
			EnableDescriptionPresent (bool): If enabled, indicates that an optional interface description is present.
			EnableLspPingCv (bool): NOT DEFINED
			EnableMaxAtmPresent (bool): Enables the generation of an interface parameter field with the maximum number of concatenated ATM cells. (default = 0)
			EnableMtuPresent (bool): This attribute enables the generation of an MTU interface parameter field.
			EnablePacking (bool): (For L2 VC FEC ranges and in Unsolicited Label Distribution Mode ONLY.) If enabled, L2 VC FEC ranges will be aggregated within a single LDP PDU to conserve bandwidth and processing.
			EnablePwAchCc (bool): NOT DEFINED
			EnablePwStatusTlv (bool): If checked, this enables the use of PW status TLV in notification messages to notify the PW status.
			EnableRouterAlertCc (bool): NOT DEFINED
			Enabled (bool): Enables use of this VC range.
			FecType (str(pwIdFec|generalizedIdFecVpls)): The FEC type. The options are: PW Id FEC 0x80, Generalized Id FEC 0x81 VPLS.
			Frequency (number): It is the frequency.
			IncludeRtpHeader (bool): If true, includes the RTP header.
			IncludeSsrc (bool): If true, enables SSRC.
			IncludeTdmBitrate (bool): If true, enables TDM bit rate.
			IncludeTdmOption (bool): If true, includes the TDM option.
			IncludeTdmPayload (bool): If true, enables TDM payload.
			IpType (number): The type (IPv4 or IPv6) of the neighbor.
			LabelMode (str(none|increment)): Indicates whether the same label or incrementing labels should be used in the VC ranges.
			LabelStart (number): The first label in the range of labels. The default is 16.
			MaxNumberOfAtmCells (number): The maximum number of ATM cells which may be concatenated and sent in a single MPLS frame. This parameter is part of the FEC element.
			Mtu (number): (in octets) The 2-octet value for the maximum Transmission Unit (MTU).
			PayloadType (number): It is the payload type.
			PeerAddress (str): The IPv4 address of the LDP router which is the peer for this VC range.
			ProvisioningModel (str(manualConfiguration|bgpAutoDiscovery)): Editable dropdown to denote the Provisioning Model.
			PwStatusCode (number): This is an editable dropdown to denote the PW status. This field is editable. The range is from 0x00000001 - 0xFFFFFFFF.
			RepeatCount (number): The number of times to repeat the above processes. The default is 1.
			SendPwStatus (bool): If checked, it signifies whether to send a notification message with a PW status for the corresponding PW.
			SourceAiiAsIp (str): The IP address.
			SourceAiiAsNumber (number): The numerical value indicating the AS of the Source AII.
			SourceAiiType (str(number|ipAddress)): Editable dropdown. The options are: AS, IP.
			Sp (str(hexVal0|hexVal1|hexVal2|hexVal3)): It signifies the SP value.
			Ssrc (number): Indicates the SSRC value.
			Step (number): The number to increment the peer address by.
			TargetAiiAsIp (str): The IP address of the Target AII.
			TargetAiiAsNumber (number): The numerical value of the Target AII.
			TargetAiiType (str(number|ipAddress)): Editable dropdown. The options are: AS, IP.
			TdmBitrate (number): The tdm bit rate.
			TdmDataSize (number): Indicates the TDM data size.
			TimestampMode (str(absolute|differential)): The time stamp mode.
			UpInterval (number): Time interval for which the same process to be repeated. (Default = 30 sec)
			VcId (number): The 32-bit VC connection identifier. Used with the VC type to identify a specific VC (for VC types 0x0001 to 0x000B).
			VcIdStep (number): The increment step to be added to each additional VC ID in the range of VC IDs.
			VplsIdAsNumber (number): The 2 byte unsigned integer value indicating the VPLS ID AS Number.
			VplsIdAsNumberStep (number): The 2 byte unsigned integer value indicating the VPLS ID AS Number Step.
			VplsIdAssignedNumber (number): The 2 or 4 byte unsigned integer value dependent on the vplsIdType
			VplsIdAssignedNumberStep (number): The 2 or 4 byte unsigned integer value dependent on the vplsIdType.
			VplsIdCount (number): The 4 byte unsigned integer indicating the VPLS ID Count.
			VplsIdIpAddress (str): The IP address of the VPLS Id.
			VplsIdIpAddressStep (str): The IP address of the VPLS Id.
			VplsIdType (str(asNumber|ipAddress)): Editable dropdown. The options are: AS, IP.

		Returns:
			self: This instance with matching l2VcRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of l2VcRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the l2VcRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)
